#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Alerts on outside bars
	/// 
	/// Code Written by Tyler Moore
	/// www.FreeIndicators.Com
	/// 
	/// For modifications to this code or to have your own custom code written
	/// please visit www.MooreTechLLC.com	
    /// </summary>
   [Description("Outside Bar Alerts\n\nwww.FreeIndicators.com")]
    public class OutsideBarAlerts : Indicator
    {
        #region Variables
        // Wizard generated variables
        private string alertFile = @"Alert1.wav"; // Default setting for AlertFile
		private Color alertBarColor = Color.Blue;
        // User defined variables (add any user defined variables below)
        #endregion

        protected override void Initialize()
        {
            Overlay				= true;
        }

        protected override void OnBarUpdate()
        {
            if (CurrentBar<1)
				return;
			
			bool highOK = High[0]>High[1];
			bool lowOK = Low[0]<Low[1];
			bool outsideBar = highOK && lowOK;
			if (outsideBar)
			{
				BarColor = alertBarColor;
				PlaySound(alertFile);
			}
        }

        #region Properties

        [Description("")]
        [GridCategory("Parameters")]
        public string AlertFile
        {
            get { return alertFile; }
            set { alertFile = value; }
        }
		
		[XmlIgnore()]
		[Description("")]
		[GridCategory("Parameters")]		
		public Color AlertBarColor
		{
			get { return alertBarColor; }
			set { alertBarColor = value; }
		}
		
		[Browsable(false)]
		public string AlertBarColorS
		{
			get { return NinjaTrader.Gui.Design.SerializableColor.ToString(alertBarColor); }
			set { alertBarColor = NinjaTrader.Gui.Design.SerializableColor.FromString(value); }
		}
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private OutsideBarAlerts[] cacheOutsideBarAlerts = null;

        private static OutsideBarAlerts checkOutsideBarAlerts = new OutsideBarAlerts();

        /// <summary>
        /// Outside Bar Alerts\n\nwww.FreeIndicators.com
        /// </summary>
        /// <returns></returns>
        public OutsideBarAlerts OutsideBarAlerts(Color alertBarColor, string alertFile)
        {
            return OutsideBarAlerts(Input, alertBarColor, alertFile);
        }

        /// <summary>
        /// Outside Bar Alerts\n\nwww.FreeIndicators.com
        /// </summary>
        /// <returns></returns>
        public OutsideBarAlerts OutsideBarAlerts(Data.IDataSeries input, Color alertBarColor, string alertFile)
        {
            if (cacheOutsideBarAlerts != null)
                for (int idx = 0; idx < cacheOutsideBarAlerts.Length; idx++)
                    if (cacheOutsideBarAlerts[idx].AlertBarColor == alertBarColor && cacheOutsideBarAlerts[idx].AlertFile == alertFile && cacheOutsideBarAlerts[idx].EqualsInput(input))
                        return cacheOutsideBarAlerts[idx];

            lock (checkOutsideBarAlerts)
            {
                checkOutsideBarAlerts.AlertBarColor = alertBarColor;
                alertBarColor = checkOutsideBarAlerts.AlertBarColor;
                checkOutsideBarAlerts.AlertFile = alertFile;
                alertFile = checkOutsideBarAlerts.AlertFile;

                if (cacheOutsideBarAlerts != null)
                    for (int idx = 0; idx < cacheOutsideBarAlerts.Length; idx++)
                        if (cacheOutsideBarAlerts[idx].AlertBarColor == alertBarColor && cacheOutsideBarAlerts[idx].AlertFile == alertFile && cacheOutsideBarAlerts[idx].EqualsInput(input))
                            return cacheOutsideBarAlerts[idx];

                OutsideBarAlerts indicator = new OutsideBarAlerts();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                indicator.AlertBarColor = alertBarColor;
                indicator.AlertFile = alertFile;
                Indicators.Add(indicator);
                indicator.SetUp();

                OutsideBarAlerts[] tmp = new OutsideBarAlerts[cacheOutsideBarAlerts == null ? 1 : cacheOutsideBarAlerts.Length + 1];
                if (cacheOutsideBarAlerts != null)
                    cacheOutsideBarAlerts.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cacheOutsideBarAlerts = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Outside Bar Alerts\n\nwww.FreeIndicators.com
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.OutsideBarAlerts OutsideBarAlerts(Color alertBarColor, string alertFile)
        {
            return _indicator.OutsideBarAlerts(Input, alertBarColor, alertFile);
        }

        /// <summary>
        /// Outside Bar Alerts\n\nwww.FreeIndicators.com
        /// </summary>
        /// <returns></returns>
        public Indicator.OutsideBarAlerts OutsideBarAlerts(Data.IDataSeries input, Color alertBarColor, string alertFile)
        {
            return _indicator.OutsideBarAlerts(input, alertBarColor, alertFile);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Outside Bar Alerts\n\nwww.FreeIndicators.com
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.OutsideBarAlerts OutsideBarAlerts(Color alertBarColor, string alertFile)
        {
            return _indicator.OutsideBarAlerts(Input, alertBarColor, alertFile);
        }

        /// <summary>
        /// Outside Bar Alerts\n\nwww.FreeIndicators.com
        /// </summary>
        /// <returns></returns>
        public Indicator.OutsideBarAlerts OutsideBarAlerts(Data.IDataSeries input, Color alertBarColor, string alertFile)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.OutsideBarAlerts(input, alertBarColor, alertFile);
        }
    }
}
#endregion
